@@ -18,8 +18,7 @@ use equivalent::{Comparable, Equivalent};
 /// An ordered map where the keys are part of the values, based on a B-Tree.
 ///
 /// The storage mechanism is a fast hash table of integer indexes to items, with
-/// these indexes stored in three b-tree maps. This allows for efficient lookups
-/// by any of the three keys, while preventing duplicates.
+/// the indexes stored in a B-Tree map.
 ///
 /// # Examples
 ///
@@ -445,8 +444,7 @@ impl<T: IdOrdItem> IdOrdMap<T> {
 
             if ix1 != ix {
                 return Err(ValidationError::General(format!(
-                    "item at index {} has mismatched indexes: ix1: {}",
-                    ix, ix1,
+                    "item at index {ix} has mismatched indexes: ix1: {ix1}",
                 )));
             }
         }
